.. _conduct:

Community Code of Conduct
=========================

ytree is a project by members of the `yt community
<http://yt-project.org/community.html>`_.  Anyone who wishes to
participate in the ytree community is expected to honor the
`yt Community Code of Conduct
<http://yt-project.org/community.html#codeofconduct>`_.
